@@ -34,3 +34,8 @@ class PV(DataSourceOutput):
         v.check_data_var_dim(v.pv_system_row_number, ("example", "id_index"))
 
         return v
+
+    @property
+    def power_normalized(self):
+        """Normalized power"""
+        return self.power_mw / self.capacity_mwp
